@@ -50,4 +50,4 @@ class IntervaledSymbol(Symbol):
             self.log_with_clock(log_level=logging.DEBUG, msg=f"Chain {chain} epoch {epoch} took {t2 - t1} seconds. ")
             return prices, returns
         except Exception as e:
-            return 'failure'
+            raise e
